@@ -27,7 +27,8 @@ def test_creation(X, y):
     assert type(endpoint.X) == pd.DataFrame
     assert type(endpoint.y) == pd.Series
     assert endpoint.y.name == "Outcome"
-    assert endpoint.func(pd.DataFrame(X)) == [0, 0, 0]
+    pred = endpoint.func(pd.DataFrame(X))
+    assert pred.equals(pd.Series([0, 0, 0]))
 
 
 @pytest.mark.parametrize("kind", ["tabular", "regression", "binary"])
@@ -44,7 +45,8 @@ def test_tabular_kinds(kind):
     assert isinstance(endpoint.X, pd.DataFrame)
     assert isinstance(endpoint.y, pd.Series)
     assert endpoint.y.name == "Outcome"
-    assert endpoint.func(pd.DataFrame(X)) == [0, 0, 0]
+    pred = endpoint.func(pd.DataFrame(X))
+    assert pred.equals(pd.Series([0, 0, 0]))
 
 
 def test_auxiliary_kind():
