@@ -4,8 +4,8 @@ from tktl.login import login, logout, validate_key, set_api_key
 
 
 class LogInCommand(CommandBase):
-    def execute(self, user_name, password, api_key=None):
-        if login(user_name, password, api_key):
+    def execute(self, api_key=None):
+        if login(api_key):
             return validate_key()
         return False
 
