@@ -1,11 +1,12 @@
 import json
 import logging
 import os
-from typing import Union, Optional, Dict
+from typing import Dict, Optional, Union
 
 import yaml
 
-from tktl.core.config import settings, Settings
+from tktl import __version__
+from tktl.core.config import Settings, settings
 from tktl.core.managers.constants import CONFIG_FILE_TEMPLATE
 
 log = logging.getLogger("root")
@@ -71,7 +72,7 @@ class BaseConfigManager(object):
         return os.path.join(base_path, cls.CONFIG_FILE_NAME)
 
     @classmethod
-    def init_config(cls, init: Union[str, bool] = None) -> None:
+    def init_config(cls, init: Union[str, bool] = False) -> None:
         cls.set_config(init=init)
 
     @classmethod
@@ -90,8 +91,9 @@ class BaseConfigManager(object):
             return
 
         if init:
-            with open(config_file_path, "w") as config_file:
-                config_file.write(CONFIG_FILE_TEMPLATE)
+            config_file = CONFIG_FILE_TEMPLATE.format(version=__version__)
+            with open(config_file_path, "w") as config_file_handle:
+                config_file_handle.write(config_file)
 
     @classmethod
     def get_config(cls) -> Optional[dict]:
