@@ -52,11 +52,12 @@ class ProjectAssetSourceT(str, ExtendedEnum):
     LFS = "lfs"
 
 
+class InstanceTypeT(str, ExtendedEnum):
+    GP_SMALL = "gp.small"
+    GP_MEDIUM = "gp.medium"
+    GP_LARGE = "gp.large"
+
+
 class ServiceT(str, ExtendedEnum):
     REST = "rest"
     GRPC = "grpc"
-
-
-class ServiceComputeT(str, ExtendedEnum):
-    GPU = "gpu"
-    CPU = "cpu"
