@@ -4,7 +4,7 @@ from functools import wraps
 import requests
 
 from tktl.core.config import settings
-from tktl.core.exceptions import InvalidInputError, AuthenticationError
+from tktl.core.exceptions import AuthenticationError, InvalidInputError
 from tktl.core.loggers import CliLogger
 from tktl.core.managers.auth import AuthConfigManager
 from tktl.core.strings import CLIStrings, HeaderStrings
@@ -52,9 +52,7 @@ def login(api_key=None):
     """
 
     if not api_key:
-        raise InvalidInputError(
-            CLIStrings.INVALID_INPUT + "api_key must be provided"
-        )
+        raise InvalidInputError(CLIStrings.INVALID_INPUT + "api_key must be provided")
 
     AuthConfigManager.set_api_key(api_key)
     return True
